;; Generated package description from orgit.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "orgit" "2.1.3" "Support for Org links to Magit buffers" '((emacs "28.1") (compat "31.0") (cond-let "1.1") (magit "4.5") (org "9.8")) :commit "4a4c03ee40b0e2509b49303e151ee217edaf0da4" :authors '(("Jonas Bernoulli" . "emacs.orgit@jonas.bernoulli.dev")) :maintainer '("Jonas Bernoulli" . "emacs.orgit@jonas.bernoulli.dev") :keywords '("hypermedia" "vc") :url "https://github.com/magit/orgit")
